# zynamon

## Synopsis

Generalized & powerful time-series class and related functions.

## Contents

This library defines a powerful time-series representation based on the well-known ```pandas``` DataFrames. However, it adds meta-data as well as conveniently built-in filtering & alignment routines for both value and time dimension. Moreover, the central time-series objects can be constructed from *nearly any 1D data* such that handling of various sources in a standardised way is made possible (e.g. regularly-sampled sensor data, event logs as well as audio streams).

As of now, this package is structured into the following modules:

**zeit**: Main module, defining classes ```TimeSeries``` and special ```TimeSpec``` as well as some helpers

**imex**: Routines for the automatic bulk import, conversion & aggregation of data from (a lot of!) CSV-files, e.g. proper extraction of all individual time-series hidden in event logs

**utils**: Helpers and routines for general analysis of TimeSeries objects and operators on two arbitrary objects, incl. routines to make objects "coherent" in time

**xutils**: Special conversion utilities for CSV-files containing DFT spectra as generated by the "CMS X-Tools" real-time multi-channel analysis software (Siemens AG).

[ Dr. Marcus Zeller | <dsp4444@gmail.com> | Erlangen, Germany | 2022-2025 ]